Drupal.behaviors.dependentFields = function(context) {
  if(!Drupal.settings.dependentfield || !$(Drupal.settings.dependentfield).length) {
    return;
  }
  jQuery.each(Drupal.settings.dependentfield, function(key, value) {
    $('select[name^='+key+'], input[name^='+key+']').checkDependentFields();
    $('select[name^='+key+'], input[name^='+key+']').bind('change', function() {
      $(this).checkDependentFields();
    });
  });
}

jQuery.fn.checkDependentFields = function() {
  if(!$(this).length) {
    return;
  }
  var name = $(this).getCleanElementName();
  if(!Drupal.settings.dependentfield[name]) {
    // This is not a dependent field.
    return;
  }
  var settings = Drupal.settings.dependentfield[name];
  
  // If there is a value property, then this is a value-dependent field
  if(settings.value) {
    if($('select[name^='+name+']').length) {
      // This is a select menu
      var selector = 'select[name^='+name+']';
    } else if ($('input[name^='+name+']').length) {
      // This is radio buttons
      var selector = 'input[name^='+name+']';
    } else {
      // This is an error
      return;
    }
    $(selector).selCheckDependentFields();
  } else {
    // This is a checkbox
    $('input[name^='+name+']').cbCheckDependentFields();
  } 
}
    
jQuery.fn.cbCheckDependentFields = function() {
  $(this).updateDependentFields($(this).is(':visible') && $(this).attr('checked'));
}

jQuery.fn.selCheckDependentFields = function() {
  var settings = Drupal.settings.dependentfield[$(this).getCleanElementName()];
  var onoff = $(this).is(':visible');
  if(onoff) {
    var i = jQuery.inArray($(this).val(), settings.value);
    onoff = i > -1;
  }
  $(this).updateDependentFields(onoff);
}

jQuery.fn.updateDependentFields = function(onoff) {
  var children = $(this).getDependentChildren();
  var name = $(this).getCleanElementName();
  var cur = $(this).val();
  if(!!Drupal.settings.dependentfield[name].value) {
    var val = Drupal.settings.dependentfield[name].value;
    var ons = new Array();
    var offs = new Array();
    jQuery.each(Drupal.settings.dependentfield[name].wrapper, function(i, child) {
      if(!!val[i] && val[i] == cur) {
        ons[i] = $('#' + child);
      } else {
        offs[i] = $('#' + child);
      }
    });
    $(this).toggleDependentFields(ons, true);
    $(this).toggleDependentFields(offs, false);
  } else {
    $(this).toggleDependentFields(children, onoff);
  }
} 

jQuery.fn.getDependentChildren = function() {
  var name = $(this).getCleanElementName();
  var children = new Array();
  if(!Drupal.settings.dependentfield[name] 
  || typeof Drupal.settings.dependentfield[name] == 'undefined'
  || !Drupal.settings.dependentfield[name].wrapper) {
    return;
  }
  
  jQuery.each(Drupal.settings.dependentfield[name].wrapper, function(i, child) {
    children[i] = $('#'+child);
  });
  return children;
}

jQuery.fn.getCleanElementName = function() {
  var name = $(this).attr('name');
  if(!!name) {
    return name.replace('[value]', '');
  }
}

jQuery.fn.toggleDependentFields = function(children, onoff) {
  if(!children || !children.length) { return; }
  jQuery.each(children, function() {
    if(onoff) {
      $(this).slideDown();
    } else {
      $(this).slideUp();
    }
  });
}
